@@ -4,15 +4,22 @@ from PyQt5 import QtCore
 from PyQt5.QtGui import QPixmap, QIcon
 from PyQt5.QtWidgets import QMainWindow, QApplication, QLabel, QFileDialog ,QPushButton,QListWidget, QCheckBox, QListWidgetItem, QComboBox
 
+
+"""This section is needed so relative paths still work dynamically once installed on the target computer"""
 this_dir,this_file = os.path.split(__file__)
 iconPath = os.path.join(str(this_dir),'res','bigicon.png')
 picPath = os.path.join(str(this_dir),'res','default.png')
+
+
 class pic:
+    """This class houses the dynamic info for each picture interacted with"""
     def __init__(self,path,name):
         self.path = path
         self.name = name
 
+
 class MainWindow(QMainWindow):
+    """this class houses the window and its elements"""
 
     def __init__(self):
         self.list = {}
@@ -20,6 +27,7 @@ class MainWindow(QMainWindow):
         super(MainWindow, self).__init__()
         self.width = 475
         self.height = 375
+        self.setFixedSize(self.width,self.height)
         self.title = "Python Image Converter - PIC"
         self.setWindowIcon(QIcon(str(iconPath)))
         self.setWindowTitle(self.title)
@@ -35,7 +43,7 @@ class MainWindow(QMainWindow):
         self.remove.setGeometry(160,10,75,50)
         self.remove.clicked.connect(self.removeItem)
 
-        #check for directory single file toggle 
+        #check for directory / single file toggle 
         self.check = QCheckBox("directory",self)
         self.check.move(90,20)
         
@@ -52,17 +60,17 @@ class MainWindow(QMainWindow):
         #drop down for file type selection
         self.cb = QComboBox(self)
         self.cb.setPlaceholderText("Format")
-        self.cb.addItems(["BMP",
-                        "DIB",
+        self.cb.addItems(["JPEG",
+                        "PNG",
                         "EPS",
                         "ICNS",
                         "ICO",
                         "IM",
-                        "JPEG",
+                        "BPM",
                         "JPEG 2000",
                         "MSP",
                         "PCX",
-                        "PNG",
+                        "DIB",
                         "PPM",
                         "SGI",
                         "TGA",
@@ -74,9 +82,6 @@ class MainWindow(QMainWindow):
         self.convert.setGeometry(300,250,120,60)
         self.convert.clicked.connect(self.convertBtn)
 
-
-
-
     
     def get_dirList(self,path):
         
@@ -86,8 +91,13 @@ class MainWindow(QMainWindow):
         dirList = os.listdir(path)
         dirList.sort()
         return dirList
-        
+
+
     def setPreview(self,path):
+
+        """
+        Sets the preview image based on the path provided
+        """
         pixmap = QPixmap(path).scaled(200,200,QtCore.Qt.IgnoreAspectRatio)
         self.label.resize(pixmap.width(),pixmap.height())
         self.label.setPixmap(pixmap)
@@ -95,8 +105,16 @@ class MainWindow(QMainWindow):
 
     
     def btnstate(self):
+
+        """
+        Checks the checkbox element to decide what type of dialog box to display
+        Stages the selected objects for use in a list
+        """
         if self.check.text() == "directory":
             if self.check.isChecked() == True:
+                """
+                this section handles directories 
+                """
                 fileNameD = QFileDialog.getExistingDirectory(self, 'Choose a Folder','C:/')
                 if fileNameD != '':            
                     files = self.get_dirList(fileNameD)
@@ -108,20 +126,23 @@ class MainWindow(QMainWindow):
                     return fileNameD
 
             else:
+                """
+                this section handles individual pictures and archives
+                """
                 fileNameF = QFileDialog.getOpenFileNames(self, 'Choose a Picture', 'C:/')
                 if fileNameF != ('', ''):
                     for i in fileNameF[0]:
                         if ".zip" in i:
+                            path = i.replace('.zip',"/")
                             with zipfile.ZipFile(i) as zf:
-                                for j in zf.infolist():
-                                    j = j.filename.split('/')[-1]
-                                    path = i.replace(i.split('.')[-1],"/")
-                                    path += j                           
-                                    if not os.path.isdir(path):
-                                        item = QListWidgetItem(j)
-                                        self.list[str(item)] = str(path)
-                                        self.fileList.addItem(item)
-                            return fileNameF
+                                zf.extractall(path)
+                            files = self.get_dirList(path)
+                            for j in files:
+                                if not os.path.isdir(path+"/"+j):
+                                    item = QListWidgetItem(j)
+                                    self.list[str(item)] = str(path+"/"+j)
+                                    self.fileList.addItem(item)
+                            return path
                     
                         else:
                             item = QListWidgetItem(i.split('/')[-1])
@@ -132,19 +153,31 @@ class MainWindow(QMainWindow):
                         
                  
     def removeItem(self):
+
+        """
+        Allows a picture to be removed from the list of staged pictures then sets the preview back to default
+        """
         item = self.fileList.currentItem()
         if item:   
             del self.list[str(self.fileList.currentItem())]
             self.fileList.takeItem(self.fileList.row(item))
             self.setPreview(str(picPath))
 
+
     def clickRow(self,row):
+
+        """
+        Allows the user too select a staged picture to preview it
+        """
         item = self.list[str(self.fileList.currentItem())]
         self.setPreview(item)
 
 
-
     def convertBtn(self):
+
+        """
+        Takes the list of staged pictures and converts them based on the file type selected in the combo box element
+        """
         for i in self.list:
             i = self.list[i]            
             ext = i.split('.')[1]
@@ -152,7 +185,6 @@ class MainWindow(QMainWindow):
             try:
                 im = Image.open(i)
                 rgb_im = im.convert('RGB')
-                print(i.replace(ext, newExt))
                 rgb_im.save(i.replace(ext, newExt), quality = 95)
             except Exception as e:
 
@@ -161,9 +193,12 @@ class MainWindow(QMainWindow):
                 else:
                     print(e)
 
-
       
 def execute():
+
+    """
+    Provides a psuedo main to be called from another file without name conflicts
+    """
     app = QApplication(sys.argv)
     w = MainWindow()
     w.show()
